/**
 * Created on 11:46 2019/04/01.
 * file name SMIcon
 * by wangtieshan
 */

import React from 'react';

import {
    EButtonOpacity,
    EImage
} from 'react-native-element';

import PropTypes from 'prop-types';

/**
 * image: '',
 * width: 8,
 * height: 12,
 * tintColor: 'gray',
 * contentMode: 'contain',
 * contentInset: { top: 0, right: 0, bottom: 0, left: 0 }
 */
export const SMIconType = {
    /*箭头*/
    arrow: {
        /*向右*/
        right: {
            image: 'el_icon_arrow_right',
            width: 8,
            height: 12,
            tintColor: 'gray'
        },
        /*向下*/
        down: {
            image: 'el_icon_arrow_down',
            width: 12,
            height: 8,
            tintColor: 'gray'
        },
        /*三角形向下的箭头*/
        triangleDown: {
            image: 'el_icon_arrow_triangle_down',
            width: 8,
            height: 6,
            tintColor: 'gray'
        },
        /*三角形向上的箭头*/
        triangleUp: {
            image: 'el_icon_arrow_triangle_up',
            width: 8,
            height: 6,
            tintColor: 'gray'
        }
    },
    /*增加*/
    add: {
        image: 'el_icon_add',
        width: 34,
        height: 34,
    },
    /*删除按钮*/
    'delete': {
        image: 'el_icon_delete',
        width: 36,
        height: 36,
    },
    /*选择*/
    select: {
        /*圆形未选中*/
        roundNormal: {
            image: 'el_icon_un_selected_round',
            width: 34,
            height: 34,
        },
        /*圆形选中*/
        roundSelected: {
            image: 'el_icon_selected_round',
            width: 34,
            height: 34,
        }
    },
    /*小马占位图*/
    horsePH: {
        image: 'el_icon_ph_horse',
        width: 80,
        height: 80,
    },
    /*圆形关闭*/
    close: {
        normal: {
            image: 'el_icon_close',
            width: 16,
            height: 16,
            tintColor: 'black',
            contentInset: { left: 7, right: 7, top: 7, bottom: 7 }
        },
        round: {
            image: 'el_icon_close_round',
            width: 20,
            height: 20,
            tintColor: 'black',
            contentInset: { left: 5, right: 5, top: 5, bottom: 5 }
        }
    },
    /*编辑*/
    edit: {
        image: 'el_icon_close_round',
        width: 18,
        height: 18,
        tintColor: 'black',
        contentInset: { left: 6, right: 6, top: 6, bottom: 6 }
    },
    /*警告*/
    warning: {
        /*大警告图片*/
        big: {
            image: 'el_icon_warning_big',
            width: 78,
            height: 78,
        },
        /*小型*/
        small: {
            image: 'el_icon_warning_big',
            width: 10,
            height: 10,
        },
        /*考虑作为一个按钮使用*/
        smallButton: {
            image: 'el_icon_warning_big',
            width: 10,
            height: 10,
            contentInset: { left: 10, right: 10, top: 10, bottom: 10 }
        }
    },
    /*过滤*/
    filter: {
        image: 'el_icon_filter',
        width: 16,
        height: 16
    },
    /*定位*/
    location: {
        image: 'el_icon_location',
        width: 17,
        height: 21
    },
    /*手机号*/
    phone: {
        image: 'el_icon_phone',
        width: 14,
        height: 14
    },
    /*定位*/
    phone: {
        image: 'el_icon_search',
        width: 16,
        height: 16
    },
    /*星星*/
    star: {
        selected: {
            image: 'el_icon_star',
            width: 12,
            height: 12
        },
        normal: {
            image: 'el_icon_star',
            width: 12,
            height: 12
        }
    }
}

/**
 * 图片icon
 */
export class SMIcon extends React.Component {

    render() {
        let typeConfig = {};
        if (this.props.type) {
            const { width, height, tintColor, contentMode = 'contain', image } = this.props.type
            typeConfig.style = { width, height }
            if (tintColor) {
                typeConfig.tintColor = tintColor;
            }
            typeConfig.contentMode = contentMode;
            const type = typeof image;
            const imageValue = (type === 'string' && { uri: image }) || (type === 'number' && image) || (type === 'object' && image);
            if (imageValue) {
                typeConfig.source = imageValue;
            }
        }
        return (
            <EImage
                {...typeConfig}
                {...this.props}
                style={[typeConfig.style, this.props.style]}/>
        )
    }
}

/**
 * 按钮 Icon
 */
export class SMIconButton extends React.Component {

    static propTypes = {
        /**
         * 类型
         */
        type: PropTypes.string,
        /**
         * 点击
         */
        onPress: PropTypes.func,
        /**
         * 禁止点击手势
         */
        disabledTouch: PropTypes.bool,
        /**
         * CSS
         */
        style: PropTypes.any,
    };

    static defaultProps = {
        disabledTouch: true
    };

    render() {
        let typeConfig = {};
        if (this.props.type) {
            const { width, height, tintColor, contentMode = 'contain', image } = this.props.type
            typeConfig.imageStyle = {  width, height }
            if (tintColor) {
                typeConfig.tintColor = tintColor;
            }
            typeConfig.contentMode = contentMode;
            if (contentInset) {
                typeConfig.contentInset = contentInset;
            }
            const type = typeof image;
            const imageValue = (type === 'string' && { uri: image }) || (type === 'number' && image) || (type === 'object' && image);
            if (imageValue) {
                typeConfig.image = imageValue;
            }
        }
        return (
            <EButtonOpacity
                {...typeConfig}
                {...this.props}
                onPress={this.props.onPress}
                style={[typeConfig.style, this.props.style]}/>
        )
    }
}
