/**
 * Created on 18:10 2019/03/12.
 * file name ERowIconTitleValueArrow
 * by wangtieshan
 */

import React from 'react';

import PropTypes from 'prop-types';

import {
    EImage,
    ETheme,
    ERowGeneral
} from '../react-native-element/Library/se';

import {
    SMIconType,
    SMIcon
} from './SMIcon';

import { ColorPropType, View } from 'react-native';

/**
 * 从左向右布局依次为：icon-title-value-image
 * 【注】只可以定义 slot 子节点为 'side' 的子节点
 */
export class SMTitleValueImage extends React.Component {

    static propTypes = {
        ...ERowGeneral.propTypes,
        /**
         * 图片节点
         */
        imageNode: PropTypes.node,
        /**
         * 图片资源
         */
        image: PropTypes.any,
        /**
         * 图片 tintColor
         */
        imageTintColor: ColorPropType,
        /**
         * 图片css
         */
        imageStyle: PropTypes.any
    };

    static defaultProps = {
        titleStyle: {
            color: ETheme.color.color9b
        },
        valueStyle: {
            color: ETheme.color.color4a
        },
    };

    render() {
        return (
            <ERowGeneral
                iconStyle={[{ borderRadius: 3, marginLeft: ETheme.css.row.sideDistance, }, this.props.iconStyle]}
                valueStyle={[{ marginRight: ETheme.css.row.sideDistance }, this.props.valueStyle]}
                {...this.props}>
                {this._customView()}
                {this.props.children}
            </ERowGeneral>
        );
    }

    _customView() {
        if (!this.props.imageNode && !this.props.image) { return; }
        return (
            <View slot={'custom'} style={{ marginHorizontal: ETheme.css.row.sideDistance  }}>
                {this.props.imageNode ||
                (this.props.image &&
                    <EImage
                        contentMode={'contain'}
                        tintColor={this.props.tintColor}
                        style={[{ width: 20, height: 20 }, this.props.imageStyle]}
                        source={this.props.image}/>
                )}
            </View>
        );
    }
}

/**
 * 用来展示的行元素。标题和内容
 */
export class SMTitleValueDisplay extends React.Component {

    static propTypes = {
        ...SMTitleValueImage.propTypes
    };

    static defaultProps = {
        height: 30,
        titleStyle: {
            color: ETheme.color.color9b
        },
        valueStyle: {
            color: ETheme.color.color4a
        },
        separatorStyle: {
            color: 'transparent'
        },
        maskOpacity: 0,
        disabledTouch: true
    };

    render() {
        return <SMTitleValueImage {...this.props} style={[{ backgroundColor: 'transparent' }, this.props.style]} />;
    }
}

/**
 * 继承自 SMTitleValueImage。增加边缘样式
 */
export class SMSideTitleValueImage extends React.Component {

    static propTypes = {
        ...SMTitleValueImage.propTypes
    };

    static defaultProps = {
        maskOpacity: 0
    };

    render() {
        return (
            <SMTitleValueImage {...this.props}>
                <View slot={'side'} style={{ width: 2, height: 25, backgroundColor: ETheme.color.main }}/>
            </SMTitleValueImage>
        );
    }
}

/**
 * 自带箭头
 */
export class SMTitleValueArrow extends React.Component {

    static propTypes = {
        ...SMTitleValueImage.propTypes,
        /**
         * 是否箭头向下。默认向右
         */
        arrowDown: PropTypes.bool
    };

    render() {
        return (
            <SMTitleValueImage
                {...this.props}
                imageNode={<SMIcon type={this.props.arrowDown ? SMIconType.arrow.down : SMIconType.arrow.right}/>}/>
        )
    }
}
